# dytop
Combinatorial dynamics and topology

## Installation
```
pip install dytop
```

or

```
git clone https://github.com/Ewerton-Vieira/dytop.git
cd dytop
pip install -e .
```

## Usage
The `examples` directory contains an example of how to use dytop. 